📦 This directory is used to include package data. Files included in this
directory will be available even after `pip install`.

⚠️ Please don't include big files in this directory since it will be included
python's site-packages repository.

🔧 The `setup.json` is used to define package specific options.
